﻿using System.Collections.ObjectModel;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace Mvc_MergePolygonsToOnePolygon.Controllers
{
    public class HomeController : Controller
    {
        // GET: Home
        public ActionResult Index()
        {
            return View();
        }

        [MapActionFilter]
        public void FindFeatureClick(Map map, GeoCollection<object> args)
        {
            PointShape position = new PointShape(double.Parse(args[0].ToString()), double.Parse(args[1].ToString()));

            LayerOverlay sourceOverlay = (LayerOverlay)map.CustomOverlays["SourceFeatureLayer"];
            LayerOverlay selectDynamicOverlay = (LayerOverlay)map.CustomOverlays["SelectDynamicOverlay"];

            InMemoryFeatureLayer sourceFeatureLayer = (InMemoryFeatureLayer)(sourceOverlay.Layers["sourceFeatureLayer"]);
            InMemoryFeatureLayer selectFeatureLayer = (InMemoryFeatureLayer)(selectDynamicOverlay.Layers["selectFeatureLayer"]);

            // Gets the features by click.
            sourceFeatureLayer.Open();
            Collection<Feature> selectedFeatures = sourceFeatureLayer.QueryTools.GetFeaturesContaining(position,ReturningColumnsType.NoColumns);
            sourceFeatureLayer.Close();

            foreach (Feature feature in selectedFeatures)
            {
                if (!selectFeatureLayer.InternalFeatures.Contains(feature.Id))
                    selectFeatureLayer.InternalFeatures.Add(feature.Id, feature);
            }
        }
        [MapActionFilter]
        public void MergeFeature(Map map, GeoCollection<object> args)
        {
            LayerOverlay selectDynamicOverlay = (LayerOverlay)map.CustomOverlays["SelectDynamicOverlay"];
            LayerOverlay resultOverlay = (LayerOverlay)map.CustomOverlays["ResultOverlay"];

            InMemoryFeatureLayer selectFeatureLayer = (InMemoryFeatureLayer)(selectDynamicOverlay.Layers["selectFeatureLayer"]);
            selectFeatureLayer.FeatureSource.Open();
            Collection<Feature> features = selectFeatureLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.NoColumns);
            selectFeatureLayer.InternalFeatures.Clear();

            Collection<PolygonShape> polygonShapes = new Collection<PolygonShape>();
            foreach (Feature feature in features)
            {
                polygonShapes.Add((PolygonShape)feature.GetShape());
            }
            // Gets the multipolygonShape which contains the selectedFeatures.
            MultipolygonShape multipolygonShape = new MultipolygonShape(polygonShapes);

            Feature newFeature = new Feature(multipolygonShape);
            // Adds the columnValues for the lable. You can add the logic of choice here.
            newFeature.ColumnValues["Name"] = "MultiPolygonShape";

            InMemoryFeatureLayer resultLayer = new InMemoryFeatureLayer();
            // Sets the areaStyle for the resultLayer.
            resultLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.County1;
            resultLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Country2("Name");
            resultLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            resultLayer.InternalFeatures.Add(newFeature);
            resultOverlay.Layers.Add(resultLayer);
        }
    }
}